export const __webpack_ids__=["475"];export const __webpack_modules__={26:function(t,e,a){Object.defineProperty(e,"__esModule",{value:!0});var l=a(3742),r=a(2894),n=a(5607);function o(t,e){if(!(t instanceof c))throw new TypeError("Method Intl.ListFormat.prototype.".concat(e," called on incompatible receiver ").concat(String(t)))}function i(t){if(void 0===t)return[];for(var e=[],a=0,l=t;a<l.length;a++){var r=l[a];if("string"!=typeof r)throw new TypeError("array list[".concat(t.indexOf(r),"] is not type String"));e.push(r)}return e}function _(t,e,a){var l=a.length;if(0===l)return[];if(2===l)return s((0,r.getInternalSlot)(t,e,"templatePair"),{0:{type:"element",value:a[0]},1:{type:"element",value:a[1]}});for(var n={type:"element",value:a[l-1]},o=l-2;o>=0;){n=s(0===o?(0,r.getInternalSlot)(t,e,"templateStart"):o<l-2?(0,r.getInternalSlot)(t,e,"templateMiddle"):(0,r.getInternalSlot)(t,e,"templateEnd"),{0:{type:"element",value:a[o]},1:n}),o--}return n}function s(t,e){for(var a=[],l=0,n=(0,r.PartitionPattern)(t);l<n.length;l++){var o=n[l],i=o.type;if((0,r.isLiteralPart)(o))a.push({type:"literal",value:o.value});else{(0,r.invariant)(i in e,"".concat(i," is missing from placables"));var _=e[i];Array.isArray(_)?a.push.apply(a,_):a.push(_)}}return a}var c=function(){function t(e,a){if(!(this&&this instanceof t?this.constructor:void 0))throw new TypeError("Intl.ListFormat must be called with 'new'");(0,r.setInternalSlot)(t.__INTERNAL_SLOT_MAP__,this,"initializedListFormat",!0);var l=(0,r.CanonicalizeLocaleList)(e),o=Object.create(null),i=(0,r.GetOptionsObject)(a),_=(0,r.GetOption)(i,"localeMatcher","string",["best fit","lookup"],"best fit");o.localeMatcher=_;var s=t.localeData,c=(0,n.ResolveLocale)(t.availableLocales,l,o,t.relevantExtensionKeys,s,t.getDefaultLocale);(0,r.setInternalSlot)(t.__INTERNAL_SLOT_MAP__,this,"locale",c.locale);var u=(0,r.GetOption)(i,"type","string",["conjunction","disjunction","unit"],"conjunction");(0,r.setInternalSlot)(t.__INTERNAL_SLOT_MAP__,this,"type",u);var p=(0,r.GetOption)(i,"style","string",["long","short","narrow"],"long");(0,r.setInternalSlot)(t.__INTERNAL_SLOT_MAP__,this,"style",p);var f=c.dataLocale,L=s[f];(0,r.invariant)(!!L,"Missing locale data for ".concat(f));var v=L[u][p];(0,r.setInternalSlot)(t.__INTERNAL_SLOT_MAP__,this,"templatePair",v.pair),(0,r.setInternalSlot)(t.__INTERNAL_SLOT_MAP__,this,"templateStart",v.start),(0,r.setInternalSlot)(t.__INTERNAL_SLOT_MAP__,this,"templateMiddle",v.middle),(0,r.setInternalSlot)(t.__INTERNAL_SLOT_MAP__,this,"templateEnd",v.end)}return t.prototype.format=function(e){o(this,"format");var a="",l=_(t.__INTERNAL_SLOT_MAP__,this,i(e));if(!Array.isArray(l))return l.value;for(var r=0,n=l;r<n.length;r++){a+=n[r].value}return a},t.prototype.formatToParts=function(e){o(this,"format");var a=_(t.__INTERNAL_SLOT_MAP__,this,i(e));if(!Array.isArray(a))return[a];for(var r=[],n=0,s=a;n<s.length;n++){var c=s[n];r.push(l.__assign({},c))}return r},t.prototype.resolvedOptions=function(){return o(this,"resolvedOptions"),{locale:(0,r.getInternalSlot)(t.__INTERNAL_SLOT_MAP__,this,"locale"),type:(0,r.getInternalSlot)(t.__INTERNAL_SLOT_MAP__,this,"type"),style:(0,r.getInternalSlot)(t.__INTERNAL_SLOT_MAP__,this,"style")}},t.supportedLocalesOf=function(e,a){return(0,r.SupportedLocales)(t.availableLocales,(0,r.CanonicalizeLocaleList)(e),a)},t.__addLocaleData=function(){for(var e=[],a=0;a<arguments.length;a++)e[a]=arguments[a];for(var l=0,r=e;l<r.length;l++){var n=r[l],o=n.data,i=n.locale,_=new Intl.Locale(i).minimize().toString();t.localeData[i]=t.localeData[_]=o,t.availableLocales.add(_),t.availableLocales.add(i),t.__defaultLocale||(t.__defaultLocale=_)}},t.getDefaultLocale=function(){return t.__defaultLocale},t.localeData={},t.availableLocales=new Set,t.__defaultLocale="",t.relevantExtensionKeys=[],t.polyfilled=!0,t.__INTERNAL_SLOT_MAP__=new WeakMap,t}();e.default=c;try{"undefined"!=typeof Symbol&&Object.defineProperty(c.prototype,Symbol.toStringTag,{value:"Intl.ListFormat",writable:!1,enumerable:!1,configurable:!0}),Object.defineProperty(c.prototype.constructor,"length",{value:0,writable:!1,enumerable:!1,configurable:!0}),Object.defineProperty(c.supportedLocalesOf,"length",{value:1,writable:!1,enumerable:!1,configurable:!0})}catch(u){}},4225:function(t,e,a){Object.defineProperty(e,"__esModule",{value:!0});var l=a(3742).__importDefault(a(26));Object.defineProperty(Intl,"ListFormat",{value:l.default,writable:!0,enumerable:!1,configurable:!0})}};
//# sourceMappingURL=475.5c62298f39c9e5b8.js.map