(self.webpackChunklcn_frontend=self.webpackChunklcn_frontend||[]).push([["951"],{3148:function(e,n,l){l(69643),l(96821),l(57900),Intl.PluralRules&&"function"==typeof Intl.PluralRules.__addLocaleData&&Intl.PluralRules.__addLocaleData({data:{categories:{cardinal:["one","other"],ordinal:["one","two","few","other"]},fn:function(e,n){var l=String(e).split("."),t=!l[1],a=Number(l[0])==e,o=a&&l[0].slice(-1),r=a&&l[0].slice(-2);return n?1==o&&11!=r?"one":2==o&&12!=r?"two":3==o&&13!=r?"few":"other":1==e&&t?"one":"other"}},locale:"en"})}}]);
//# sourceMappingURL=951.1b5500bfa9a3b512.js.map