export const __webpack_ids__=["951"];export const __webpack_modules__={3148:function(e,o,t){t(7900),Intl.PluralRules&&"function"==typeof Intl.PluralRules.__addLocaleData&&Intl.PluralRules.__addLocaleData({data:{categories:{cardinal:["one","other"],ordinal:["one","two","few","other"]},fn:function(e,o){var t=String(e).split("."),l=!t[1],a=Number(t[0])==e,n=a&&t[0].slice(-1),r=a&&t[0].slice(-2);return o?1==n&&11!=r?"one":2==n&&12!=r?"two":3==n&&13!=r?"few":"other":1==e&&l?"one":"other"}},locale:"en"})}};
//# sourceMappingURL=951.1ed15f8c3a28d391.js.map