export const __webpack_ids__=["754"];export const __webpack_modules__={5799:function(e,n,o){Object.defineProperty(n,"__esModule",{value:!0});var t=o(3389);"undefined"==typeof Intl&&("undefined"!=typeof window?Object.defineProperty(window,"Intl",{value:{}}):"undefined"!=typeof global&&Object.defineProperty(global,"Intl",{value:{}})),Object.defineProperty(Intl,"getCanonicalLocales",{value:t.getCanonicalLocales,writable:!0,enumerable:!1,configurable:!0})}};
//# sourceMappingURL=754.f4ff6ea50c94051b.js.map