"use strict";(self.webpackChunklcn_frontend=self.webpackChunklcn_frontend||[]).push([["475"],{70026:function(t,e,a){a(57900),a(73249),a(84730),a(20289),a(40777),a(12212),a(87622),a(26847),a(2394),a(92377),a(28273),a(54480),a(56303),a(11353),a(67886),a(65451),a(46015),a(38334),a(94880),a(75643),a(29761),a(48694),a(52530),a(27530),Object.defineProperty(e,"__esModule",{value:!0});var l=a(73742),n=a(12894),r=a(99625);function o(t,e){if(!(t instanceof c))throw new TypeError("Method Intl.ListFormat.prototype.".concat(e," called on incompatible receiver ").concat(String(t)))}function i(t){if(void 0===t)return[];for(var e=[],a=0,l=t;a<l.length;a++){var n=l[a];if("string"!=typeof n)throw new TypeError("array list[".concat(t.indexOf(n),"] is not type String"));e.push(n)}return e}function _(t,e,a){var l=a.length;if(0===l)return[];if(2===l)return s((0,n.getInternalSlot)(t,e,"templatePair"),{0:{type:"element",value:a[0]},1:{type:"element",value:a[1]}});for(var r={type:"element",value:a[l-1]},o=l-2;o>=0;){r=s(0===o?(0,n.getInternalSlot)(t,e,"templateStart"):o<l-2?(0,n.getInternalSlot)(t,e,"templateMiddle"):(0,n.getInternalSlot)(t,e,"templateEnd"),{0:{type:"element",value:a[o]},1:r}),o--}return r}function s(t,e){for(var a=[],l=0,r=(0,n.PartitionPattern)(t);l<r.length;l++){var o=r[l],i=o.type;if((0,n.isLiteralPart)(o))a.push({type:"literal",value:o.value});else{(0,n.invariant)(i in e,"".concat(i," is missing from placables"));var _=e[i];Array.isArray(_)?a.push.apply(a,_):a.push(_)}}return a}var c=function(){function t(e,a){if(!(this&&this instanceof t?this.constructor:void 0))throw new TypeError("Intl.ListFormat must be called with 'new'");(0,n.setInternalSlot)(t.__INTERNAL_SLOT_MAP__,this,"initializedListFormat",!0);var l=(0,n.CanonicalizeLocaleList)(e),o=Object.create(null),i=(0,n.GetOptionsObject)(a),_=(0,n.GetOption)(i,"localeMatcher","string",["best fit","lookup"],"best fit");o.localeMatcher=_;var s=t.localeData,c=(0,r.ResolveLocale)(t.availableLocales,l,o,t.relevantExtensionKeys,s,t.getDefaultLocale);(0,n.setInternalSlot)(t.__INTERNAL_SLOT_MAP__,this,"locale",c.locale);var u=(0,n.GetOption)(i,"type","string",["conjunction","disjunction","unit"],"conjunction");(0,n.setInternalSlot)(t.__INTERNAL_SLOT_MAP__,this,"type",u);var p=(0,n.GetOption)(i,"style","string",["long","short","narrow"],"long");(0,n.setInternalSlot)(t.__INTERNAL_SLOT_MAP__,this,"style",p);var f=c.dataLocale,L=s[f];(0,n.invariant)(!!L,"Missing locale data for ".concat(f));var v=L[u][p];(0,n.setInternalSlot)(t.__INTERNAL_SLOT_MAP__,this,"templatePair",v.pair),(0,n.setInternalSlot)(t.__INTERNAL_SLOT_MAP__,this,"templateStart",v.start),(0,n.setInternalSlot)(t.__INTERNAL_SLOT_MAP__,this,"templateMiddle",v.middle),(0,n.setInternalSlot)(t.__INTERNAL_SLOT_MAP__,this,"templateEnd",v.end)}return t.prototype.format=function(e){o(this,"format");var a="",l=_(t.__INTERNAL_SLOT_MAP__,this,i(e));if(!Array.isArray(l))return l.value;for(var n=0,r=l;n<r.length;n++){a+=r[n].value}return a},t.prototype.formatToParts=function(e){o(this,"format");var a=_(t.__INTERNAL_SLOT_MAP__,this,i(e));if(!Array.isArray(a))return[a];for(var n=[],r=0,s=a;r<s.length;r++){var c=s[r];n.push(l.__assign({},c))}return n},t.prototype.resolvedOptions=function(){return o(this,"resolvedOptions"),{locale:(0,n.getInternalSlot)(t.__INTERNAL_SLOT_MAP__,this,"locale"),type:(0,n.getInternalSlot)(t.__INTERNAL_SLOT_MAP__,this,"type"),style:(0,n.getInternalSlot)(t.__INTERNAL_SLOT_MAP__,this,"style")}},t.supportedLocalesOf=function(e,a){return(0,n.SupportedLocales)(t.availableLocales,(0,n.CanonicalizeLocaleList)(e),a)},t.__addLocaleData=function(){for(var e=[],a=0;a<arguments.length;a++)e[a]=arguments[a];for(var l=0,n=e;l<n.length;l++){var r=n[l],o=r.data,i=r.locale,_=new Intl.Locale(i).minimize().toString();t.localeData[i]=t.localeData[_]=o,t.availableLocales.add(_),t.availableLocales.add(i),t.__defaultLocale||(t.__defaultLocale=_)}},t.getDefaultLocale=function(){return t.__defaultLocale},t.localeData={},t.availableLocales=new Set,t.__defaultLocale="",t.relevantExtensionKeys=[],t.polyfilled=!0,t.__INTERNAL_SLOT_MAP__=new WeakMap,t}();e.default=c;try{"undefined"!=typeof Symbol&&Object.defineProperty(c.prototype,Symbol.toStringTag,{value:"Intl.ListFormat",writable:!1,enumerable:!1,configurable:!0}),Object.defineProperty(c.prototype.constructor,"length",{value:0,writable:!1,enumerable:!1,configurable:!0}),Object.defineProperty(c.supportedLocalesOf,"length",{value:1,writable:!1,enumerable:!1,configurable:!0})}catch(u){}},44225:function(t,e,a){Object.defineProperty(e,"__esModule",{value:!0});var l=a(73742).__importDefault(a(70026));Object.defineProperty(Intl,"ListFormat",{value:l.default,writable:!0,enumerable:!1,configurable:!0})}}]);
//# sourceMappingURL=475.f1df737bad118e1e.js.map